==> haskell-shakespeare-2.1.0.1-40-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-shakespeare.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 shakespeare
version:              2.1.0.1
visibility:           public
id:                   shakespeare-2.1.0.1-9R6Wj2KyUxuAyLJOW020KL
key:                  shakespeare-2.1.0.1-9R6Wj2KyUxuAyLJOW020KL
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/shakespearean-templates
synopsis:             A toolkit for making compile-time interpolated templates
description:
    Shakespeare is a family of type-safe, efficient template languages. Shakespeare templates are expanded at compile-time, ensuring that all interpolated variables are in scope. Variables are interpolated according to their type through a typeclass.

    Shakespeare templates can be used inline with a quasi-quoter or in an external file.

    Note there is no dependency on haskell-src-extras. Instead Shakespeare believes logic should stay out of templates and has its own minimal Haskell parser.

    Packages that use this: xml-hamlet

    Please see the documentation at <http://www.yesodweb.com/book/shakespearean-templates> for more details.

category:             Web, Yesod
abi:                  baf7078a640912be409130e95c449b93
exposed:              True
exposed-modules:
    Text.Cassius Text.Cassius.Ordered Text.Coffee Text.Hamlet
    Text.Hamlet.RT Text.Hamlet.Runtime Text.Internal.Cassius
    Text.Internal.Css Text.Internal.CssCommon Text.Internal.Lucius
    Text.Julius Text.Lucius Text.Lucius.Ordered Text.Roy
    Text.Shakespeare Text.Shakespeare.Base Text.Shakespeare.I18N
    Text.Shakespeare.Text Text.TypeScript

hidden-modules:       Text.Hamlet.Parse Text.MkSizeType Text.IndentToBrace
import-dirs:          /usr/lib/ghc-9.2.8/site-local/shakespeare-2.1.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/shakespeare-2.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-shakespeare
hs-libraries:         HSshakespeare-2.1.0.1-9R6Wj2KyUxuAyLJOW020KL
depends:
    aeson-2.1.2.1-6EBV889cSS7AqjoZtYoje8 base-4.16.4.0
    blaze-html-0.9.1.2-6wRAerZ4BzkA8WiagtXagU
    blaze-markup-0.8.3.0-3lhSB69YCfDDQ7BetUpwCx bytestring-0.11.4.0
    containers-0.6.5.1 directory-1.3.6.2 exceptions-0.10.4
    file-embed-0.0.15.0-4hNEx1vJ7JTC58fR03LKND ghc-prim-0.8.0
    parsec-3.1.15.0 process-1.6.16.0
    scientific-0.3.7.0-KUJ0yQBDqbB75MLhDe7uzc template-haskell-2.18.0.0
    text-1.2.5.0 th-lift-0.8.4-7yLYwH7OaPD4aJs3FpHkYY time-1.11.1.1
    transformers-0.5.6.2
    unordered-containers-0.2.20-6SQIi6GiFzoJl2Kyo4GEMQ
    vector-0.13.1.0-FqETZo7rR6n5zX4PwJIjNh

haddock-interfaces:   /usr/share/doc/haskell-shakespeare/html/shakespeare.haddock
haddock-html:         /usr/share/doc/haskell-shakespeare/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-shakespeare-2.1.0.1-43-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-shakespeare.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 shakespeare
version:              2.1.0.1
visibility:           public
id:                   shakespeare-2.1.0.1-2NHB0ezf08SJJqwX9xaPqB
key:                  shakespeare-2.1.0.1-2NHB0ezf08SJJqwX9xaPqB
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/shakespearean-templates
synopsis:             A toolkit for making compile-time interpolated templates
description:
    Shakespeare is a family of type-safe, efficient template languages. Shakespeare templates are expanded at compile-time, ensuring that all interpolated variables are in scope. Variables are interpolated according to their type through a typeclass.

    Shakespeare templates can be used inline with a quasi-quoter or in an external file.

    Note there is no dependency on haskell-src-extras. Instead Shakespeare believes logic should stay out of templates and has its own minimal Haskell parser.

    Packages that use this: xml-hamlet

    Please see the documentation at <http://www.yesodweb.com/book/shakespearean-templates> for more details.

category:             Web, Yesod
abi:                  a97b8275271c15caa558de743f7114ae
exposed:              True
exposed-modules:
    Text.Cassius Text.Cassius.Ordered Text.Coffee Text.Hamlet
    Text.Hamlet.RT Text.Hamlet.Runtime Text.Internal.Cassius
    Text.Internal.Css Text.Internal.CssCommon Text.Internal.Lucius
    Text.Julius Text.Lucius Text.Lucius.Ordered Text.Roy
    Text.Shakespeare Text.Shakespeare.Base Text.Shakespeare.I18N
    Text.Shakespeare.Text Text.TypeScript

hidden-modules:       Text.Hamlet.Parse Text.MkSizeType Text.IndentToBrace
import-dirs:          /usr/lib/ghc-9.2.8/site-local/shakespeare-2.1.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/shakespeare-2.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-shakespeare
hs-libraries:         HSshakespeare-2.1.0.1-2NHB0ezf08SJJqwX9xaPqB
depends:
    aeson-2.1.2.1-BDwFFwggpmOFR96vAdYTat base-4.16.4.0
    blaze-html-0.9.1.2-6wRAerZ4BzkA8WiagtXagU
    blaze-markup-0.8.3.0-3lhSB69YCfDDQ7BetUpwCx bytestring-0.11.4.0
    containers-0.6.5.1 directory-1.3.6.2 exceptions-0.10.4
    file-embed-0.0.15.0-4hNEx1vJ7JTC58fR03LKND ghc-prim-0.8.0
    parsec-3.1.15.0 process-1.6.16.0
    scientific-0.3.7.0-KUJ0yQBDqbB75MLhDe7uzc template-haskell-2.18.0.0
    text-1.2.5.0 th-lift-0.8.4-7yLYwH7OaPD4aJs3FpHkYY time-1.11.1.1
    transformers-0.5.6.2
    unordered-containers-0.2.20-FcLWwyBCSKkJfk374YGHrL
    vector-0.13.1.0-FqETZo7rR6n5zX4PwJIjNh

haddock-interfaces:   /usr/share/doc/haskell-shakespeare/html/shakespeare.haddock
haddock-html:         /usr/share/doc/haskell-shakespeare/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
